@@ -442,8 +442,10 @@ mvRWTS <- function(times, data, error=NULL, param=list(sigma=NULL, trend=FALSE,
     
     # AIC
     AIC<- -2*LL+2*nparam
+    
     # AIC corrected
-    AICc<-AIC+((2*nparam*(nparam+1))/(n-nparam-1)) # Hurvich et Tsai, 1989
+    nobs <- length(which(!is.na(data)))
+    AICc<-AIC+((2*nparam*(nparam+1))/(nobs-nparam-1)) # Hurvich et Tsai, 1989
     
     ##-------------------Print results--------------------------------------------##
     if(echo==TRUE){
