@@ -510,7 +510,8 @@ mvOUTS <- function(times, data, error=NULL, param=list(sigma=NULL,alpha=NULL, vc
     # AIC
     AIC<- -2*LL+2*nparam
     # AIC corrected
-    AICc<-AIC+((2*nparam*(nparam+1))/(n-nparam-1)) # Hurvich et Tsai, 1989
+    nobs <- length(which(!is.na(data)))
+    AICc<-AIC+((2*nparam*(nparam+1))/(nobs-nparam-1)) # Hurvich et Tsai, 1989
     # matrix of estimated theta values
     theta.mat<-matrix(theta.mat,ncol=p)
     if(root==TRUE){
